#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 insert-ordered-containers
version:              0.2.5
visibility:           public
id:                   insert-ordered-containers-0.2.5-2SyqL4YkK326MBCs83asXO
key:                  insert-ordered-containers-0.2.5-2SyqL4YkK326MBCs83asXO
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/insert-ordered-containers#readme
synopsis:
    Associative containers retaining insertion order for traversals.

description:
    Associative containers retaining insertion order for traversals.

    The implementation is based on `unordered-containers`.

category:             Web
abi:                  a5e3a2a6a455aa3c54459f00ce9104dc
exposed:              True
exposed-modules:      Data.HashMap.Strict.InsOrd Data.HashSet.InsOrd
hidden-modules:       Data.HashMap.InsOrd.Internal
import-dirs:
    /usr/lib/ghc-8.10.5/site-local/insert-ordered-containers-0.2.5

library-dirs:
    /usr/lib/ghc-8.10.5/site-local/insert-ordered-containers-0.2.5

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/i386-linux-ghc-8.10.5/insert-ordered-containers-0.2.5

hs-libraries:         HSinsert-ordered-containers-0.2.5-2SyqL4YkK326MBCs83asXO
depends:
    aeson-1.5.6.0-CVfeYccFVpdCde0UrZZZdZ base-4.14.2.0
    base-compat-0.11.2-Eyusxyk2CrTGloLdon9bIK deepseq-1.4.4.0
    hashable-1.3.2.0-GpzwVyCMdDv8NwdC61S1EE
    indexed-traversable-0.1.1-1Z2GfU1EWlL3ZzMnGNHsA4
    lens-5.0.1-9j09gzxg2dR5Wmd3U39g28
    optics-core-0.4-ASCFnMeArQt2z7PKRP4hO3
    optics-extra-0.4-LN5OufKsydJKNArgrARXT1
    semigroupoids-5.3.5-CXCAmgAqO2AH1F4bh8bCjo text-1.2.4.1
    transformers-0.5.6.2
    unordered-containers-0.2.14.0-JpdjDmlqBJN4PAu3jIj4Ya

haddock-interfaces:
    /usr/share/doc/haskell-insert-ordered-containers/html/insert-ordered-containers.haddock

haddock-html:         /usr/share/doc/haskell-insert-ordered-containers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

